General astroML Examples
------------------------

This section contains several example plots which do not appear in the
textbook.  Currently there are only a few examples here: for more, please
see the :ref:`text book figures <book_fig_root>`.
